/*
 * This file is part of Danbooru Client.
 * Copyright 2013  Luca Beltrame <lbeltrame@kde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef DANBOORU_CLIENT_H
#define DANBOORU_CLIENT_H


#include <KXmlGuiWindow>

namespace Danbooru {

    class DanbooruClientView;
    class DanbooruService;
    class DanbooruPostModel;
    class DanbooruConnectWidget;

    /**
     * This class serves as the main window for danbooru_client.  It handles the
     * menus, toolbars and status bars.
     *
     * @short Main window class
     * @author Luca Beltrame <lbeltrame@kde.org>
     * @version 0.01
     */
    class DanbooruMainWindow : public KXmlGuiWindow
    {
        Q_OBJECT
    public:
        /**
         * Default Constructor
         */
        DanbooruMainWindow();

        /**
         * Default Destructor
         */
        virtual ~DanbooruMainWindow();

    private Q_SLOTS:
        void connectToBoard();
        void downloadPosts();
        void optionsPreferences();

    private:
        void setupActions();
        void setupConnections();

    private:
        DanbooruClientView *m_view;
        DanbooruPostModel* m_model;
        DanbooruService* m_service;
        DanbooruConnectWidget* m_connectWidget;


    };
} // namespace Danbooru

#endif // _DANBOORU_CLIENT_H_
